@@ -3,7 +3,7 @@ use pyo3::prelude::*;
 mod classes;
 mod stack_graphs_wrapper;
 
-use classes::{Indexer, Language, Position, Querier};
+use classes::{FileEntry, FileStatus, Indexer, Language, Position, Querier};
 
 /// Formats the sum of two numbers as string.
 #[pyfunction]
@@ -34,6 +34,8 @@ fn stack_graphs_python(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(index, m)?)?;
     m.add_class::<Position>()?;
     m.add_class::<Language>()?;
+    m.add_class::<FileStatus>()?;
+    m.add_class::<FileEntry>()?;
     m.add_class::<Querier>()?;
     m.add_class::<Indexer>()?;
     Ok(())
